@@ -45,3 +45,24 @@ our @EXPORT = qw(
 );
 
 1;
+
+__END__
+
+=head1 NAME
+
+BERT::Constants - Various constants for BERT serialization
+
+=head1 AUTHOR
+
+Sherwin Daganato E<lt>sherwin@daganato.comE<gt>
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+L<BERT>
+
+=cut
